@@ -124,8 +124,7 @@ async def exitTelethon():
 def getText(soup):
     soup = copy.copy(soup)
     for item in soup.find_all('a'):
-        if (item.get('href') and not isUrl(item.text) and 
-                not item.get('href').startswith('?q=')):
+        if item.get('href') and not item.get('href').startswith('?q='):
             item.replace_with('\n\n' + item.get('href') + '\n\n')
     for item in soup.find_all('br'):
         item.replace_with('\n')
